#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Only
version:              0.1
visibility:           public
id:                   Only-0.1-FUCJUAPDXF54dPZ4SnGX6G
key:                  Only-0.1-FUCJUAPDXF54dPZ4SnGX6G
license:              BSD-3-Clause
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
synopsis:             The 1-tuple type or single-value "collection"
description:
    This package provides the canonical anonymous 1-tuple type missing from Haskell for attaching typeclass instances.

category:             Data
abi:                  4dfbe783cab45e8ce82c2067afde88e0
exposed:              True
exposed-modules:      Data.Tuple.Only
import-dirs:          /usr/lib/ghc-8.10.5/site-local/Only-0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/Only-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/Only-0.1
hs-libraries:         HSOnly-0.1-FUCJUAPDXF54dPZ4SnGX6G
depends:              base-4.14.2.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-only/html/Only.haddock
haddock-html:         /usr/share/doc/haskell-only/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

